@@ -9,20 +9,18 @@
 
 ;; This file is not part of GNU Emacs.
 
-;; deb-view is free software; you can redistribute it and/or modify
+;; deb-view.el is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
-;; any later version.
+;; the Free Software Foundation, either version 2 of the License, or
+;; (at your option) any later version.
 
-;; deb-view is distributed in the hope that it will be useful,
+;; deb-view.el is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with deb-view; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -273,7 +271,7 @@ See also the variable deb-find-directory."
 (define-key debview-mode-map "u"    'undefined)
 (define-key debview-mode-map "x"    'undefined)
 (define-key debview-mode-map ""   'undefined)
-             
+
 (define-key debview-mode-map "?"    'deb-view-help)
 (define-key debview-mode-map "q"    'deb-view-dired-view-cleanup)
 (define-key debview-mode-map "N"    'deb-view-tar-man)
@@ -324,11 +322,6 @@ In dired, press ^d on the dired line of the .deb file to view.
 Or, execute: ESCAPE x deb-view RETURN, and enter the .deb file name
 at the prompt."
   (interactive "fdeb file to view: ")
-  (if (and (or (string-match "Lucid" emacs-version)
- 	       (string-match "XEmacs" emacs-version))
- 	   (>= emacs-major-version 21))
-      (require 'view-less)
-    (require 'view))
   (require 'view)
   (if (< (nth 1 (file-attributes debfile)) 0)
       (progn
@@ -366,8 +359,7 @@ at the prompt."
           (save-excursion
             (set-buffer file-buffer)
             (erase-buffer)
-            (call-process shell-file-name nil t nil shell-command-switch
-                          (concat "file " debfile))
+            (call-process "file" nil '(t t) debfile)
             (goto-char 1)
             (if (string-match "archive" (buffer-string))
                 t
@@ -380,8 +372,7 @@ at the prompt."
     (cond
      (new-archive-format
       ;; New deb format (archive)
-      (call-process shell-file-name nil t nil shell-command-switch
-                    (concat "dpkg-deb --ctrl-tarfile " debfile))
+      (call-process "dpkg-deb" nil '(t t) nil "--ctrl-tarfile" debfile)
       (goto-char 1)
       (setq buffer-file-name (concat deb-view-file-name "-INFO"))
       (if (fboundp 'set-buffer-multibyte) (set-buffer-multibyte nil))
@@ -399,8 +390,7 @@ at the prompt."
      (t
       ;; Old deb format
       (message "deb-view old dpkg binary format")
-      (call-process shell-file-name nil t nil shell-command-switch
-                    (concat "dpkg-deb -I " debfile))
+      (call-process "dpkg-deb" nil '(t t) nil "-I"  debfile)
       (setq buffer-read-only t)
       (set-buffer-modified-p nil)
       (goto-char 1)
@@ -446,8 +436,7 @@ at the prompt."
           (error "%s: Not a valid package file" deb-view-buffer-name))
         (call-process-region (point-min) (point-max) "xz" t t nil "-cd"))))
      (t      
-      (call-process shell-file-name nil t nil shell-command-switch
-                    (concat "dpkg-deb --fsys-tarfile " debfile))))
+      (call-process "dpkg-deb" '(t t) nil "--fsys-tarfile " debfile)))
     (goto-char 1)
     (setq buffer-file-name (concat deb-view-file-name "-DATA"))
     (if (fboundp 'set-buffer-multibyte) (set-buffer-multibyte nil))
@@ -498,7 +487,7 @@ easily repeat a `deb-find' command."
   (interactive)
   (require 'compile)
   (let* ((deb-file-string (read-from-minibuffer "deb file to find: "
-                                         nil nil nil 'deb-find-history))
+						nil nil nil 'deb-find-history))
          (output-buffer-name "*deb-find*")
          (command (cond ((string-equal deb-find-method "locate")
                          (concat "locate '" deb-file-string
@@ -652,7 +641,9 @@ If the file is from the INFO buffer, then open in the other (larger) window."
                    ("\\.Z$"  . deb-view-tar-uncompress-while-visiting)
                    ) auto-mode-alist)))
     (if (string-match "INFO$" buffer-file-name)
-        (tar-extract-other-window)
+        (progn
+          (tar-extract-other-window)
+          (view-buffer (current-buffer) 'kill-buffer-if-not-modified))
       (tar-extract 'view))))
 
 (defun deb-view-tar-w3 ()
